@@ -295,13 +295,13 @@ def get_reference_df(reference_data, likely_reference_IDs=None):
     extension = reference_data.rsplit('.',1)
     extension = extension[(len(extension)-1)]
     if extension == 'mgf' or extension == 'MGF' or extension == 'mzML' or extension == 'mzml' or extension == 'MZML' or extension == 'cdf' or extension == 'CDF':
-        output_path_tmp = reference_data[:-3] + 'csv'
+        output_path_tmp = reference_data[:-3] + 'txt'
         build_library_from_raw_data(input_path=reference_data, output_path=output_path_tmp, is_reference=True)
-        df_reference = pd.read_csv(output_path_tmp)
-    if extension == 'csv' or extension == 'CSV':
-        df_reference = pd.read_csv(reference_data)
+        df_reference = pd.read_csv(output_path_tmp, sep='\t')
+    if extension == 'txt' or extension == 'TXT':
+        df_reference = pd.read_csv(reference_data, sep='\t')
     if likely_reference_IDs is not None:
-        likely_reference_IDs = pd.read_csv(likely_reference_IDs, header=None)
+        likely_reference_IDs = pd.read_csv(likely_reference_IDs, header=None, sep='\t')
         df_reference = df_reference.loc[df_reference.iloc[:,0].isin(likely_reference_IDs.iloc[:,0].tolist())]
     return df_reference
 
